@@ -440,6 +440,83 @@ qt_nonstandard <- function(p, df = 1, mu = 0, sigma = 1, lower.tail = TRUE, log.
   .Call(C_qt_nonstandard, as.double(p), as.double(df), as.double(mu), as.double(sigma), as.logical(lower.tail), as.logical(log.p))
 }
 
+#' The Double Exponential (Laplace) Distribution
+#'
+#' Density, distribution function, quantile function and random generation
+#' for the double exponential distribution,
+#' allowing non-zero location, \code{mu},
+#' and non-unit scale, \code{sigma}, or non-unit rate, \code{tau} 
+#'
+#' @name Double-Exponential 
+#' 
+#' @param x vector of values.
+#' @param n number of observations.
+#' @param p vector of probabilities.
+#' @param q vector of quantiles.
+#' @param location vector of location values.
+#' @param scale vector of scale values.
+#' @param rate vector of inverse scale values.
+#' @param log logical; if TRUE, probability density is returned on the log scale.
+#' @param log.p logical; if TRUE, probabilities p are given by user as log(p).
+#' @param lower.tail logical; if TRUE (default) probabilities are \eqn{P[X \le x]}; otherwise, \eqn{P[X > x]}.
+#' @author Christopher Paciorek
+#' @details See Gelman et al., Appendix A or the BUGS manual for mathematical details. 
+#' @return \code{ddexp} gives the density, \code{pdexp} gives the distribution
+#' function, \code{qdexp} gives the quantile function, and \code{rdexp}
+#' generates random deviates.
+#' @references Gelman, A., Carlin, J.B., Stern, H.S., and Rubin, D.B. (2004) \emph{Bayesian Data Analysis}, 2nd ed. Chapman and Hall/CRC.
+#' @seealso \link{Distributions} for other standard distributions
+#' 
+#' @examples
+#' x <- rdexp(50, location = 2, scale = 1)
+#' ddexp(x, 2, 1)
+NULL
+
+#' @rdname Double-Exponential
+#' @export
+ddexp <- function(x, location = 0, scale = 1, rate = 1/scale, log = FALSE) {
+  if (!missing(scale) && !missing(rate)) {
+      if (abs(scale * rate - 1) < 1e-15) 
+          warning("specify 'scale' or 'rate' but not both")
+      else stop("specify 'scale' or 'rate' but not both")
+  }
+  .Call(C_ddexp, as.double(x), as.double(location), as.double(scale), as.logical(log))
+}
+
+#' @rdname Double-Exponential
+#' @export
+rdexp <- function(n, location = 0, scale = 1, rate = 1/scale) {
+  if (!missing(scale) && !missing(rate)) {
+      if (abs(scale * rate - 1) < 1e-15) 
+          warning("specify 'scale' or 'rate' but not both")
+      else stop("specify 'scale' or 'rate' but not both")
+  }
+  .Call(C_rdexp, as.integer(n), as.double(location), as.double(scale))
+}
+
+#' @rdname Double-Exponential
+#' @export
+pdexp <- function(q, location = 0, scale = 1, rate = 1/scale, lower.tail = TRUE, log.p = FALSE) {
+  if (!missing(scale) && !missing(rate)) {
+      if (abs(scale * rate - 1) < 1e-15) 
+          warning("specify 'scale' or 'rate' but not both")
+      else stop("specify 'scale' or 'rate' but not both")
+  }
+  .Call(C_pdexp, as.double(q), as.double(location), as.double(scale), as.logical(lower.tail), as.logical(log.p))
+}
+
+#' @rdname Double-Exponential
+#' @export
+qdexp <- function(p, location = 0, scale = 1, rate = 1/scale, lower.tail = TRUE, log.p = FALSE) {
+  if (!missing(scale) && !missing(rate)) {
+      if (abs(scale * rate - 1) < 1e-15) 
+          warning("specify 'scale' or 'rate' but not both")
+      else stop("specify 'scale' or 'rate' but not both")
+  }
+  .Call(C_qdexp, as.double(p), as.double(location), as.double(scale), as.logical(lower.tail), as.logical(log.p))
+}
+
+
 #' The Multivariate Normal Distribution
 #'
 #' Density and random generation for the multivariate normal distribution, using the Cholesky factor of either the precision matrix or the covariance matrix.
@@ -822,7 +899,6 @@ rsqrtinvgamma <- function(n = 1, shape, scale = 1, rate = 1/scale) {
     .Call(C_rsqrtinvgamma, as.integer(n), as.double(shape), as.double(rate))
 }
 
-
 #' The CAR-Normal Distribution
 #'
 #'   Density function and random generation for the improper (intrinsic)
